[java-idp-integration-tests] branch main updated: Fix path to idp.home for the OP on Windows

Tom Zeller tzeller at dragonacea.biz
Mon Sep 9 22:29:07 UTC 2024


This is an automated email from the git hooks/post-receive script.

tzeller pushed a commit to branch main
in repository java-idp-integration-tests.

View the commit online:
http://git.shibboleth.net/view/?p=java-idp-integration-tests.git;a=commit;h=7874e00625853b22570e518c1cdb0b076f738178

The following commit(s) were added to refs/heads/main by this push:
     new 7874e00  Fix path to idp.home for the OP on Windows
7874e00 is described below

commit 7874e00625853b22570e518c1cdb0b076f738178
Author: Tom Zeller <tzeller at dragonacea.biz>
AuthorDate: Mon Sep 9 17:28:58 2024 -0500

    Fix path to idp.home for the OP on Windows
---
 src/test/java/net/shibboleth/idp/integration/tests/oidc/RPTest.java | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/test/java/net/shibboleth/idp/integration/tests/oidc/RPTest.java b/src/test/java/net/shibboleth/idp/integration/tests/oidc/RPTest.java
index 0cc2618..3415db1 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/oidc/RPTest.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/oidc/RPTest.java
@@ -460,8 +460,8 @@ public class RPTest extends BaseOPTest {
         // Make tmp directories exist
         Assert.assertTrue(pathToOpJettyBase.resolve("tmp").toFile().exists(), "Path to jetty.base/tmp/ not found");
 
-        // set idp.home system property
-        opServerCommands.add(0, "-Didp.home=" + pathToOP.toAbsolutePath().toString());
+        // Set idp.home system property, replace '\' with '/' for Windows
+        opServerCommands.add(0, "-Didp.home=" + pathToOP.toAbsolutePath().toString().replace('\\', '/'));
 
         // set tmp directory system property
         serverCommands.add("-Djava.io.tmpdir=" + pathToOpJettyBase.resolve("tmp").toAbsolutePath());

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list